@@ -10,13 +10,14 @@ from .core import date  # Scalar
 from .core import datetime  # Scalar
 from .core import decimal  # Scalar
 from .core import field  # Tool - Field
-from .core import is_model  # Tool - is_model?
+from .core import is_model  # Tool | is-model?
 from .core import json  # Scalar
 from .core import load  # Tool - Load
 from .core import text  # Scalar
 from .core import time  # Scalar
 from .core import type  # Type
+from .core import is_form # Tool | is-form?
 
 # Forms
-from .forms import Form as form # Tool - Create Forms
-from .manager import manager # Tool - Querying Manager
+from .forms import Form as form  # Tool - Create Forms
+from .manager import manager  # Tool - Querying Manager
